@@ -1,11 +1,11 @@
 # __init__.py
 # Copyright 2010 Roger Marsh
 # Licence: See LICENCE (BSD licence)
-'''Portable Game Notation (PGN) parser.
+"""Portable Game Notation (PGN) parser.
 
 Data structures used when parsing PGN or Forsythe Edwards Notation (FEN) text
 are defined in the "constants" module.  PGN is game scores and FEN is positions
 in a game.
 
 PGN and FEN parsing is implemented in the "parser" module.
-'''
+"""
