@@ -14,13 +14,15 @@ argument and adds it to the instance of game.Game class, or susubclass, in the
 game argument.
 
 """
-import os
 import re
 
 from .game import (
-    Game, GameStrictPGN, GameTextPGN, GameIgnoreCasePGN,
-    import_format, text_format,
-    )
+    Game,
+    GameTextPGN,
+    GameIgnoreCasePGN,
+    import_format,
+    text_format,
+)
 
 from .constants import (
     IGNORE_CASE_FORMAT,
@@ -48,14 +50,15 @@ from .constants import (
     IFG_BAD_COMMENT,
     IFG_BAD_RESERVED,
     IFG_BAD_TAG,
+    IFG_END_OF_FILE_MARKER,
     IFG_OTHER_WITH_NON_NEWLINE_WHITESPACE,
-    )
+)
 
 ignore_case_format = re.compile(IGNORE_CASE_FORMAT)
 
 
 class PGNError(Exception):
-    pass
+    """Exception raised for situations where PGN parsing cannot continue."""
 
 
 class PGN:
@@ -73,7 +76,7 @@ class PGN:
     'e4*'
     '[TagName"Tag Value"]e4*'
     '[TagName"Tag Value"]e4e5Nf3Nc6Bb5*'
-    
+
     The last of the examples would be '[TagName"Tag Value"]e4 e5 Nf3 Nc6 Bb5*'
     in text valid according to the PGN Import Format specification: the spaces
     inserted between the moves.
@@ -86,7 +89,9 @@ class PGN:
     decides which, if any, interpretation is valid.
 
     """
+
     def __init__(self, game_class=Game):
+        """Initialise switches to call game_class methods."""
         super().__init__()
         if issubclass(game_class, GameIgnoreCasePGN):
             self._rules = ignore_case_format
@@ -132,8 +137,9 @@ class PGN:
             game_class.append_token_and_set_error,
             game_class.append_token_and_set_error,
             game_class.append_bad_tag_and_set_error,
+            game_class.ignore_end_of_file_marker_prefix_to_tag,
             game_class.append_other_or_disambiguation_pgn,
-            )
+        )
         self.error_despatch_table = (
             None,
             game_class.append_token_after_error,
@@ -166,7 +172,8 @@ class PGN:
             game_class.append_token_after_error,
             game_class.append_bad_tag_after_error,
             game_class.append_token_after_error,
-            )
+            game_class.append_token_after_error,
+        )
 
     @staticmethod
     def _read_pgn(source, length):
@@ -181,7 +188,7 @@ class PGN:
                     break
         finally:
             source.close()
-    
+
     def read_games(self, source, size=10000000):
         """Extract games from file-like source or string.
 
@@ -195,14 +202,14 @@ class PGN:
         despatch_table = self.despatch_table
         error_despatch_table = self.error_despatch_table
         game_class = self._game_class
-        residue = ''
+        residue = ""
         for pgntext in self._read_pgn(source, size):
 
             # The previous chunk of pgntext may have ended with an incomplete
             # game, with or without errors.
             if residue:
                 pgntext = residue + pgntext
-                residue = ''
+                residue = ""
             residue_start_on_error_at_pgntext_end = None
 
             game = game_class()
@@ -265,8 +272,7 @@ class PGN:
                     game.set_game_error()
                 residue = pgntext
             else:
-                residue = pgntext[
-                    residue_start_on_error_at_pgntext_end:]
+                residue = pgntext[residue_start_on_error_at_pgntext_end:]
 
         # The final game in the input has an error, or has no error but no game
         # termination marker either.
@@ -276,7 +282,10 @@ class PGN:
 
 
 def add_token_to_game(text, game, pos=0):
-    """Apply first match in text after pos to game and return match end point.
+    """Apply first match in text after pos to game and return match.end().
+
+    Return None if no match found.
+
     """
     if isinstance(game, GameIgnoreCasePGN):
         match = ignore_case_format.search(text, pos)
@@ -308,7 +317,7 @@ def add_token_to_game(text, game, pos=0):
         elif lastindex == IFG_DOTS:
             game.append_token_after_error_without_separator(match)
         elif lastindex == IFG_CHECK_INDICATOR:
-            game.append_token_after_error_without_separator(match),
+            game.append_token_after_error_without_separator(match)
         else:
             game.append_token_after_error(match)
         return match.end()
@@ -349,17 +358,19 @@ def add_token_to_game(text, game, pos=0):
     elif lastindex == IFG_PASS:
         game.append_pass_and_set_error(match)
     elif lastindex == IFG_CHECK_INDICATOR:
-        game.ignore_check_indicator(match),
+        game.ignore_check_indicator(match)
     elif lastindex == IFG_TRADITIONAL_ANNOTATION:
-        game.append_glyph_for_traditional_annotation(match),
+        game.append_glyph_for_traditional_annotation(match)
     elif lastindex == IFG_BAD_COMMENT:
-        game.append_token_and_set_error(match),
+        game.append_token_and_set_error(match)
     elif lastindex == IFG_BAD_RESERVED:
-        game.append_token_and_set_error(match),
+        game.append_token_and_set_error(match)
     elif lastindex == IFG_BAD_TAG:
-        game.append_bad_tag_and_set_error(match),
+        game.append_bad_tag_and_set_error(match)
     elif lastindex == IFG_OTHER_WITH_NON_NEWLINE_WHITESPACE:
         game.append_other_or_disambiguation_pgn(match)
+    elif lastindex == IFG_END_OF_FILE_MARKER:
+        game.ignore_end_of_file_marker_prefix_to_tag(match)
     else:
         game.append_token_and_set_error(match)
     return match.end()
