@@ -8,6 +8,6 @@ from ..core.game import Game
 from ._utilities import main
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
-    main(game_class=Game, samples_title='Sample PGN File Report')
+    main(game_class=Game, samples_title="Sample PGN File Report")
