@@ -8,7 +8,8 @@ from ._utilities import main
 from ..core.game import GameStrictPGN
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
-    main(game_class=GameStrictPGN,
-         samples_title='Sample Strict PGN File Report')
+    main(
+        game_class=GameStrictPGN, samples_title="Sample Strict PGN File Report"
+    )
