@@ -8,6 +8,6 @@ from ._utilities import main
 from ..core.game import GameTextPGN
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
-    main(game_class=GameTextPGN, samples_title='Sample Text PGN File Report')
+    main(game_class=GameTextPGN, samples_title="Sample Text PGN File Report")
